#
# spec file for package remind
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           remind
Version:        3.3.9
Release:        bp154.1.18
%define tar_version 03.03.09
Summary:        A sophisticated calendar and alarm program
License:        GPL-2.0-only
Group:          Productivity/Office/Organizers
URL:            http://www.roaringpenguin.com/products/remind
Source0:        %{name}-%{tar_version}.tar.gz
Source100:      %{name}-%{version}-rpmlintrc
Patch0:         remind-nostrip.patch
BuildRequires:  perl
BuildRequires:  perl-Getopt-Long-Descriptive
BuildRequires:  perl-JSON-Any
Requires:       perl
Requires:       perl-Getopt-Long-Descriptive
Requires:       perl-JSON-Any
Requires:       tcllib

%description
Remind is a sophisticated calendar and alarm program.
It includes the following features:

* A sophisticated scripting language and intelligent
  handling of exceptions and holidays.
* Plain-text, PostScript and HTML output.
* Timed reminders and pop-up alarms.
* A friendly graphical front-end for people who don't
  want to learn the scripting language.
* Facilities for both the Gregorian and Hebrew calendars.
* Support for 12 different languages.

%prep
%setup -q -n %{name}-%{tar_version}
%patch0 -p1

%build
CFLAGS="%{optflags}" ./configure --prefix=%{_prefix}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

##%%check
##make test

%files
%defattr(-,root,root,-)
%doc %{_mandir}/man1/rem.1%{ext_man}
%doc %{_mandir}/man1/rem2ps.1%{ext_man}
%doc %{_mandir}/man1/remind.1%{ext_man}
%doc %{_mandir}/man1/tkremind.1%{ext_man}

%{_bindir}/rem
%attr(0755,root,root) %{_bindir}/rem2ps
%attr(0755,root,root) %{_bindir}/remind
%attr(0755,root,root) %{_bindir}/tkremind
%attr(0755,root,root) %{_bindir}/rem2html

%changelog
* Fri Oct 15 2021 Detlef Steuer <detlef.steuer@gmx.de>
- rem2html is included, cleanup of specfile
- CHANGES TO REMIND
  * VERSION 3.3 Patch 9 - 2021-10-14
- NEW FEATURE: Add "-+username" option to tell Remind to trust files owned by
  "username" and allow RUN directives in them.  Idea courtesy of Ian! D. Allen
- NEW FEATURE: Add "-u+username" variant to tell Remind to switch users to
  "username" without disabling RUN directives.  Idea courtesy of Ian! D. Allen
- CHANGE: rem2html: rem2html has been moved out of the www/ directory into
  its own rem2html/ directory.  If your system has the prerequisites
  (namely Perl, Getopt::Long and JSON::Any) then rem2html will be installed
  by "make install".
- CHANGE: Remove "cm2rem".  It was about 20 years obsolete.
- CHANGE: rem2html: Use inline data: URL images for moon images by default,
  thus producing a completely stand-alone HTML file.
- CHANGE: Remove unnecessary spaces from "remind -pp" JSON output.
- DOCUMENTATION FIX: Various man page fixes and tweaks.
- BUG FIX: rem2html: Tweak the default CSS stylesheet; more rational
  handling of rem2html command-line options.
- BUG FIX: remind: "remind -c" would sometimes highlight *two* days as
  "today"; this has been fixed.
- BUG FIX: Add a missing #ifdef...#endif and remove a C99-ism.  This once again
  allows Remind to be compiled with some very old C compilers.
* Tue Sep 14 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 8 - 2021-09-13
- NEW FEATURE: remind: Add INCLUDECMD command
- NEW FEATURE: remind: Add shellescape() built-in function
- BUG FIX: tkremind: TkRemind would sometimes fill in incorrect initial
  values for the reminder-editing form if you clicked on a TkRemind-created
    reminder to edit it.  This has been fixed.
- BUG FIX: tkremind: Get back better error messages from Remind if you
  try to create a reminder with an invalid date specification.
- BUG FIX: remind: Catch integer overflow if we try to evaluate $IntMin * -1
- DOC UPDATES: remind: Minor man page fixes
* Tue May 11 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 7 - 2021-05-10
- MINOR FIX: Refuse to run "make test" as root --- it would fail
  anyway with an obscure message.
- BUG FIX: Remind would sometimes compute incorrect trigger date for:
  REM Tue 29 Feb MSG ...
- BUG FIX: Remind would sometimes compute incorrect trigger date for
  a date spec like: Tue 31 2021 MSG ...
* Tue Mar 30 2021 Detlef Steuer <detlef.steuer@gmx.de>
- CHANGES TO REMIND
  * VERSION 3.3 Patch 6 - 2021-03-30
- test/test.rem: Change local to en_US.utf-8 only if current locale
  is not a UTF-8 locale.
- MINOR CHANGE: Remind's arithemtic operators (+, -, *, /) give errors
  on overflow rather than silently giving the wrong answer.
- MINOR CHANGE: Add $IntMin and $IntMax system variables.
- DOCUMENTATION FIX: Document that TkRemind now requires Tcl/Tk version
  8.5 or newer.
* Fri Jan 22 2021 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.5
- CHANGES TO REMIND
  * VERSION 3.3 Patch 5 - 2021-01-21
- NEW FEATURE: tkremind: Add ability to change fonts and colors from
  within TkRemind "Options" dialog.
- CHANGE: tkremind: TkRemind now requires Tcl/Tk 8.5 or newer.
- CHANGE: tkremind: You can specify the location of the options
  file on the command-line if you want to use one other than ~/.tkremindrc
- CLEANUP: tkremind: Remove "Apply Options" from Options dialog; we only
  need "Save Options".
- DOC FIX: Add missing release note in 3.3.4 notes regarding
  setpagedevice patch
- DOC FIX: tkremind: Document shortcut keys.
* Tue Jan 12 2021 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.4
- CHANGES TO REMIND
  * VERSION 3.3 Patch 4 - 2021-01-12
- NEW FEATURE: If "inotifywait" is installed, TkRemind uses it to refresh
  the calendar display right away when the reminders file/directory is updated.
  This makes TkRemind react almost instantly if external tools are editing
  or updating reminders.
- MINOR NEW FEATURE: rem2ps has a new '-x' option; this puts the day numbers
  on the top-left of the day's box instead of the top-right.
- MINOR FIXES: A typo in remind.1 was fixed; additional comments regarding
  UNTIL were added.
- BUG FIX: rem2ps: Call setpagedevice to set page size
  Based on a patch from Jonathan Kamens
* Mon Nov  9 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.3
- CHANGES TO REMIND
  * VERSION 3.3 Patch 3 - 2020-11-09
- BUG FIX: Fix startup crash in TkRemind if "Show Today's Reminders on
  Startup" is enabled (which, unfortunately, is the default.)  Bug reported
  by Martin Ziemer.
* Sun Nov  8 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.2
- CHANGES TO REMIND
  * VERSION 3.3 Patch 2 - 2020-11-08
- MINOR NEW FEATURE: Add MAYBE-UNCOMPUTABLE keyword; see the man page
  and discussion at
  https://dianne.skoll.ca/pipermail/remind-fans/2020/003745.html
- CHANGE: TkRemind always invokes Remind with the "-itkremind=1" option,
  even when printing.  NOTE INCOMPATIBILITY: This is a behavior change!
  When you print from TkRemind, we also invoke Remind with "-itkprint=1"
  so you can detect that PostScript is being generated.
- CHANGE: The maxmimum length of a variable name has been increased from
  16 characters to 64 characters.  Modern computers have plenty of memory.
- BUG FIXES: Minor documentation updates, typo fixes, clarifications, etc.
- BUG FIX: Fix calendar-drawing alignment errors when displaying UTF-8
  strings with zero-width combining characters and strings with tabs.
- BUG FIX: TkRemind would mess up placement of the WEEK special if invoked
  with the "-m" option.  This has been fixed.
- BUG FIX: TkRemind would sometimes fail with an error message when editing
  a reminder; this is because it was interpreting months 08 and 09 as
  illegal octal numbers.  This has been fixed.
* Fri Mar 20 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind 3.3.1
- CHANGE: For overlapping multi-day events, issue a reminder for the
  most *recent* event rather than the earliest event.  NOTE
  INCOMPATIBILITY: This is a behavior change!
- CHANGE: Do not convert 90-99 to 1990-1999 when parsing numbers to
  recognize years.  NOTE INCOMPATIBILITY: This is a behavior change!
- CHANGE: Revert change to -y option that included filename and line
  number in the hash.
- CHANGE: Retain newlines (produced by %%_) in JSON output.
- FIX: Document $FormWidth system variable
- FIX: Highlight today's date in "remind -c" output
- FIX: Eliminate compiler warnings on Ubuntu 18.04.
- IMPROVEMENT: Allow times to be specified either in 24-hour mode
  (HH:MM or HH.MM) or AM/PM mode (HH:MMam; HH:MMpm, etc.)
- IMPROVEMENT: Allow DURATION to be specified as a time (1:30) or a
  number of minutes (90).
- IMPROVEMENT: If terminal size can be determined, set $FormWidth to
  terminal width - 8; if not, set $FormWidth to 72.
- MINOR IMPROVEMENT: Add the "ampm()" built-in function.
* Sat Feb  1 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind-3.3.0
- FIX: rem2ps: Add a %%%%PageBoundingBox: document structuring convention
  comment.
- FIX: rem2ps: Ignore unknown SPECIAL-type reminders.
- IMPROVEMENT: In calendar mode ("-c" option), Remind automatically adjusts
  the width of the calendar to fit the terminal window if standard output
  is a TTY.
- IMPROVEMENT: Add JSON-based output with "remind -pp" and "remind -ppp"
  The JSON-based intermediate format preserves a lot more information
  about the original reminder, allowing back-ends more insight into
  the intent of the reminder, the recurrence used, etc.  See the documentation
  in "man rem2ps"
- IMPROVEMENT: TkRemind can "reverse-engineer" reminders that it creates
  using the additional information in the "remind -pp" format, so it
  doesn't create or use ugly comment blocks to delimit the reminders
  it creates.
- IMPROVEMENT: TkRemind: Add popup help to most buttons and controls.
- NEW FEATURE: Add support for $DefaultColor system variable, suggested
  by Tim Chase.
- NEW FEATURE: The "-@[n][,m]" command-line option allows colored reminders
  in Agenda Mode as well as in Calendar Mode.  It also adds support for
  terminal emulators that can handle the xterm 256-color escape sequences
  as well as the true 24-bit color escape sequences.
- CHANGE: SPECIALs are now case-insensitive.  Before, only SPECIAL COLOR
  would work.  Now you can use Special Color, special color, etc.
* Sat Jan  4 2020 Detlef Steuer <detlef.steuer@gmx.de>
- defattr still needed to support SLE11-SP4
* Sat Jan  4 2020 Detlef Steuer <detlef.steuer@gmx.de>
- update to remind-3.2.0
- removed buildroot and defattr calls from spec. No londer needed.
- IMPROVEMENT: Add support for events spanning multiple days (with AT
  and DURATION).  Add trigeventstart() and trigeventduration()
  introspection functions; see "MULTI-DAY EVENTS" in the man page.
- IMPROVEMENT: Add introspection functions trigback(), trigdelta(),
  trigduration(), trigfrom(), trigpriority(), trigrep(),
  trigscanfrom(), trigtimedelta(), trigtimerep(), and triguntil().  See
  man page for details; thanks to Tim Chase for the suggestion.
- IMPROVEMENT: TkRemind: Use PNG images for the next month / previous
  month buttons rather than -> and <-.  Also use nice anti-aliased
  moon phase images instead of ugly blocky bitmaps.
- CHANGE: Modify addition so that previously-illegal combinations
  TIME + TIME, TIME + DATETIME and DATETIME + TIME are now allowed.
  Also allow DATETIME - TIME.  If t1 and t2 are expressions of type TIME
  and dt is an expression of type DATETIME, then the following are now
  equivalent (before, the expressions on the left-hand side would fail
  with a "Type mismatch" error.)
  t1 + t2     ==     t1                + coerce("INT", t2)
  dt + t2     ==     dt                + coerce("INT", t2)
  t1 + dt     ==     coerce("INT", t1) + dt
  dt - t2     ==     dt                - coerce("INT", t2)
- DOC FIX: Document previously-undocumented $MaxStringLen system variable
- DOC FIX: Various minor documentation fixes.
- BUG FIX: Specifying a DURATION without an AT clause results in an error.
  Before, it would be accepted but not do anything useful.
- BUG FIX: Catch potential date overflow in slide() function
- BUG FIX: Fix compile error when compiling Romanian version; eliminate
  compiler warning when compiling non-English versions.
- BUG FIX: TkRemind: Fix startup failure of TkRemind if options are at
  default. :(
* Fri Aug 14 2015 puzel@suse.com
- update to remind-3.1.15
  - BUG FIX: Fix a buffer overflow found by Alexander Keller
    (CVE-2015-5957)
  - BUG FIX: Make parser reject an AT followed by more than one time.
  - BUG FIX: Make parser reject repeated delta or *repeat values.
  - NEW FEATURE: Putting the line __EOF__ in a .rem file causes
    Remind to treat it as end-of-file.
  - IMPROVEMENT: Use better PNG images for moons in the HTML display
  - BUG FIX: The "-n" command-line option should really run in
    "ADVANCE_MODE" rather than "CAL_MODE" internally; otherwise,
    the substitution sequences may be misinterpreted.
  - BUG FIX: A typo in clearing out MD5 sum context has been fixed.
  - BUG FIX: Typo in Spanish translation was fixed.
* Mon Apr 22 2013 puzel@suse.com
- update to remind-3.1.13
  - BUG FIX: Sunrise/Sunset calculations greatly improved thanks to
    John McGowan.  Accuracy should now be within a couple of
    minutes in most places.
  - BUG FIX: Allow specification of margins as low as 0 points in
    rem2ps, courtesy of Jonathan Kamens.
  - BUG FIX: Permit compilation with gcc 2.95 (which doesn't allow
    variable declarations after non-declaration statements in a
    block.)
  - BUG FIX: Several minor documentation errors corrected courtesy
    of Simon Ruderich.
  - BUG FIX: Spurious test harness failure was fixed.
* Tue Feb 28 2012 puzel@suse.com
- update to remind-3.1.12
  - NEW FEATURE: Many substitution sequences "%%x" have an alternate
    mode denoted by "%%*x".  This alternate mode leaves out
    prepositions.  For example, in English "%%i" might yield "on
    01-25" while "%%*i" yields only "01-25".
  - BUG FIX: The "dusk" and "dawn" calculations were completely
    wrong.  They have been fixed.  Also, sunrise/sunset calculations
    have been tweaked, so the results may be off by a minute or two
    compared to previous versions of Remind.
  - BUG FIX: For some inexplicable reason, dawn was considered to
    happen when the sun was 14 degrees below the horizon instead of
    the standard 6 degrees for Civil Dawn.  This has been fixed.
  - BUG FIXES: Clarified the man pages and fixed some typos.
  - BUG FIX: Add THROUGH to the remind.vim syntax highlighting file.
  - ENHANCEMENT (?): Allow SPECIAL COLOR to be spelled SPECIAL
    COLOUR.
  - BUG FIX: Apply minor Debian cleanups reported by Kurt B. Kaiser.
* Mon Feb 20 2012 mrdocs@opensuse.org
- disable make check - it breaks the build
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 22 2010 puzel@novell.com
- clean up specfile
- enable 'make check' again
* Tue Nov  2 2010 puzel@novell.com
- update to remind-3.1.10
  - add the THROUGH keyword.  You can omit blocks of dates
    with: OMIT start THROUGH end
  - add support for multibyte characters (eg, UTF-8) in calendar
    output. Note that UTF-8 strings are still not supported in
    PostScript output.
  - add support for UTF-8 line-drawing characters in calendar
    output
  - you can have multiple TAG clauses in a REM statement
  - avoid spawning long-running background processes in "make
    test"
  - don't declare variables in the middle of statements (old C
    compilers choke.)
* Mon Jun 21 2010 puzel@novell.com
- update to remind-3.1.9
  - New "purge mode" to delete expired reminders. See
    the PURGE MODE section of the remind man page.
  - Support DURATION in TkRemind. Thanks to Marek Marczykowski.
  - Don't change the order of PS and PSFILE reminders.  Bug found
    by John McGowan.
  - "REM 1990-01-01 SATISFY 1" would yield a spurious parse error
    in earlier versions of Remind.
  - Yom HaShoah is moved to Thursday if it would normally fall on
    a Friday. Thanks to Jonathan Kamens for pointing this out.
* Wed Mar 10 2010 puzel@novell.com
- update to remind-3.1.8
  - Add the $T, $Td, $Tm, $Tw, $Ty, $U, $Ud, $Um, $Uw, $Uy
    special variables to make reminder files less wordy. See man page
    for details.
  - Ignore msgprefix() and msgsuffix() on RUN-type reminders.
  - Adjust Remind and Rem2PS so that SHADE specials don't obliterate
    earlier MOON specials.
  - Fix bug in SCHED calculations if Remind is started in the middle
    of a SCHED interval.
* Fri Jan 22 2010 puzel@novell.com
- initial package for Contrib, based on obs://home:code933k/remind
